<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://themeforest.net/user/kamleshyadav
 * @since      1.0.0
 *
 * @package    Fc
 * @subpackage Fc/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Fc
 * @subpackage Fc/admin
 * @author     Kamleshyadav <support@pixelnx.com>
 */
class Fc_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
	
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Fc_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Fc_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		
		 wp_enqueue_style('plugin-fonts', plugin_dir_url( __FILE__ ) . 'css/fonts.css', array(), $this->version, 'all' );
		 wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/fc-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Fc_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Fc_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/fc-admin.js', array( 'jquery' ), $this->version, false );

	}
	/**
	 * Fitness calculator admin menu
	 */
	public function fc_admin_menus(){
		/**
		 * Dashboard Menu
		 */
		add_menu_page(
			esc_html__('Fitness Calculator','fc'),
			esc_html__('Fitness Calculator','fc'),
			'manage_options',
			'fitness-cal',
			array($this,'fitness_cal_setting'),
			'dashicons-calculator',
			7
		);
		
	}
	/**
	 * Fitness calculator settings
	 */
	public function fitness_cal_setting(){
		$bmidata = $iweight_sw = $bodyfat_sw = $bmi_sw = $bmiheading = $bfp_sw = $enable = $bmienable = $bfpenable = $bodyfatenable = $iweightenable = $heightenable = $columnsec = '';
		$bmidata = get_option('fc_bmidata');
		if(!empty($bmidata['heading'])){
			$bmiheading = $bmidata['heading'];
		}
		if(!empty($bmidata['bmi_sw'])){
			$bmi_sw = $bmidata['bmi_sw'];
			if($bmi_sw == 'on'){
				$bmienable = esc_attr__('checked','fc');
			}
			else{
				$bmienable = esc_attr__(' ','fc');
			}
		}
		if(!empty($bmidata['bmi_bfp_sw'])){
			$bfp_sw = $bmidata['bmi_bfp_sw'];
			if($bfp_sw == 'on'){
				$bfpenable = esc_attr__('checked','fc');
			}
			else{
				$bfpenable = esc_attr__(' ','fc');
			}
		}
		if(!empty($bmidata['bmi_bodyfat_sw'])){
			$bodyfat_sw = $bmidata['bmi_bodyfat_sw'];
			if($bodyfat_sw == 'on'){
				$bodyfatenable = esc_attr__('checked','fc');
			}
			else{
				$bodyfatenable = esc_attr__(' ','fc');
			}
		}
		if(!empty($bmidata['bmi_iweight_sw'])){
			$iweight_sw = $bmidata['bmi_iweight_sw'];
			if($iweight_sw == 'on'){
				$iweightenable = esc_attr__('checked','fc');
			}
			else{
				$iweightenable = esc_attr__(' ','fc');
			}
		}
		$bmi_columnsec_sw = $columnsecenable = '';
		if(!empty($bmidata['bmi_columnsec_sw'])){
			$bmi_columnsec_sw = $bmidata['bmi_columnsec_sw'];
			if($bmi_columnsec_sw == 'on'){
				$columnsecenable = esc_attr__('checked','fc');
			}
			else{
				$columnsecenable = esc_attr__(' ','fc');
			}
		}
		
		//water intake calculator
		$wicheading = '';
		$wicdata = get_option('fc_wicdata');
		if(!empty($wicdata['heading'])){
			$wicheading = $wicdata['heading'];
		}
		
		//Calories Calculator 
		$ccheading = $colsecenable = '';
		$ccdata = get_option('fc_scc');
		if(!empty($ccdata['heading'])){
			$ccheading = $ccdata['heading'];
		}
		$calorie_columnsec = '';
		if(!empty($ccdata['calorie_columnsec'])){
			$calorie_columnsec = $ccdata['calorie_columnsec'];
			if($calorie_columnsec == 'on'){
				$colsecenable = esc_attr__('checked','fc');
			}
			else{
				$colsecenable = esc_attr__(' ','fc');
			}
		}
		
		//Health Quote
		$quotedata = get_option('fc_quotedata');
		$quote_status = $quote_position = $statusenable = $exclass= '';
		if(!empty($quotedata['quote_status'])){
			$quote_status = $quotedata['quote_status'];
			if($quote_status == 'on'){
				$statusenable = esc_attr__('checked','fc');
			}
			else{
				$statusenable = esc_attr__(' ','fc');
			}
		}  
		if(!empty($quotedata['fc_position'])){
			$quote_position = $quotedata['fc_position'];
			$exclass = esc_attr__('selected','fc');
		} 
		
		// Blood Type Data
		$fc_btdata = $btenable = $bt_column = '';
		$fc_btdata = get_option('fc_btdata');
		if(!empty($fc_btdata['bt_column'])){
		    $bt_column = $fc_btdata['bt_column'];
		    if($bt_column == 'on'){
				$btenable = esc_attr__('checked','fc');
			}
			else{
				$btenable = esc_attr__(' ','fc');
			}
		}
		
		// Walking Test Data
		$fc_wtdata = $wtenable = $wt_column = '';
		$fc_wtdata = get_option('fc_wtdata');
		if(!empty($fc_wtdata['wt_column'])){
		    $wt_column = $fc_wtdata['wt_column'];
		    if($wt_column == 'on'){
				$wtenable = esc_attr__('checked','fc');
			}
			else{
				$wtenable = esc_attr__(' ','fc');
			}
		}

		//General Settings
		$gensettings = get_option('fc_gensettings');
		$primarycolor = $textcolor = $titlecolor = $fontfamily = $ffclass = $inputbg = $inputcolor = $socialpage = $bordercolor = '';
		if(!empty($gensettings['fc_primarycolor'])){
			$primarycolor = $gensettings['fc_primarycolor'];
		}
		if(!empty($gensettings['fc_titlecolor'])){
			$titlecolor = $gensettings['fc_titlecolor'];
		}
		if(!empty($gensettings['fc_textcolor'])){
			$textcolor = $gensettings['fc_textcolor'];
		}
		
		if(!empty($gensettings['fc_bgcolor'])){
			$bgcolor = $gensettings['fc_bgcolor'];
		}
		
		if(!empty($gensettings['fc_inputbg'])){
			$inputbg = $gensettings['fc_inputbg'];
		}
		if(!empty($gensettings['fc_inputcolor'])){
			$inputcolor = $gensettings['fc_inputcolor'];
		}
		if(!empty($gensettings['fc_bordercolor'])){
			$bordercolor = $gensettings['fc_bordercolor'];
		}
		
		if(!empty($gensettings['fc_socialpage'])){
			$socialpage = $gensettings['fc_socialpage'];
		}
		
		if(!empty($gensettings['fc_fontfamily'])){
			$fontfamily = $gensettings['fc_fontfamily'];
			if($fontfamily == 'on'){
				$ffclass = esc_attr__('checked','fc');
			}
			else{
				$ffclass = esc_attr__(' ','fc');
			}
		}
		
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/fc-admin-display.php';
	}

	/**
	 * Save Admin Panel Option Into Database
	 */
	public function fc_save_option() {
		if( !empty( $_POST['fc_sbmi'] ) ){
			$bmidata['heading']        = isset( $_POST['fc_bmihead'] ) ? sanitize_text_field( wp_unslash ( $_POST['fc_bmihead'] ) ) : array();
			$bmidata['bmi_sw']         = isset( $_POST['bmi_sw'] ) ? sanitize_text_field( wp_unslash ( $_POST['bmi_sw'] ) ) : array();
			$bmidata['bmi_bfp_sw']     = isset( $_POST['bmi_bfp_sw'] ) ? sanitize_text_field( wp_unslash ( $_POST['bmi_bfp_sw'] ) ) : array();
			$bmidata['bmi_bodyfat_sw'] = isset( $_POST['bmi_bodyfat_sw'] ) ? sanitize_text_field( wp_unslash ( $_POST['bmi_bodyfat_sw'] ) ) : array();
			$bmidata['bmi_iweight_sw'] = isset( $_POST['bmi_iweight_sw'] ) ? sanitize_text_field( wp_unslash ( $_POST['bmi_iweight_sw'] ) ) : array();
			$bmidata['bmi_columnsec_sw']  = isset( $_POST['bmi_columnsec_sw'] ) ? sanitize_text_field( wp_unslash ( $_POST['bmi_columnsec_sw'] ) ) : array();
			
			$result = update_option('fc_bmidata', $bmidata);
			if(!empty($result)){
				add_action( 'admin_notices', array($this, 'vrs_admindata__success') );
			}
		}
		if( !empty( $_POST['fc_swic'] ) ){
			$wicdata['heading']        = isset( $_POST['fc_wihead'] ) ? sanitize_text_field( wp_unslash ( $_POST['fc_wihead'] ) ) : array();
			$result = update_option('fc_wicdata', $wicdata);
			if(!empty($result)){
				add_action( 'admin_notics', array($this, 'vrs_Admindata__success') );
			}
		}
		if( !empty( $_POST['fc_scc'] ) ){
			$ccdata['heading']        = isset( $_POST['fc_cchead'] ) ? sanitize_text_field( wp_unslash ( $_POST['fc_cchead'] ) ) : array();
			$ccdata['calorie_columnsec']        = isset( $_POST['calorie_columnsec_sw'] ) ? sanitize_text_field( wp_unslash ( $_POST['calorie_columnsec_sw'] ) ) : array();
			$result = update_option('fc_scc', $ccdata);
			if(!empty($result)){
				add_action( 'admin_notices', array($this, 'vrs_admindata__success') );
			}
		}
		if(!empty($_POST['fc_quote'])){
			$quotedata['quote_status']        = isset( $_POST['quote_status'] ) ? sanitize_text_field( wp_unslash ( $_POST['quote_status'] ) ) : array();
			$quotedata['fc_position']         = isset( $_POST['fc_position'] ) ? sanitize_text_field( wp_unslash ( $_POST['fc_position'] ) ) : array();
			$result = update_option('fc_quotedata', $quotedata);
			if(!empty($result)){
				add_action( 'admin_notices', array($this, 'vrs_admindata__success') );
			}
		}
		if(!empty($_POST['fc_general_form'])){
			$generalsetting['fc_primarycolor'] = isset( $_POST['fc_primarycolor'] ) ? sanitize_text_field( wp_unslash ( $_POST['fc_primarycolor'] ) ) : array();
			$generalsetting['fc_titlecolor']   = isset( $_POST['fc_titlecolor'] ) ? sanitize_text_field( wp_unslash ( $_POST['fc_titlecolor'] ) ) : array();
			$generalsetting['fc_textcolor']    = isset( $_POST['fc_textcolor'] ) ? sanitize_text_field( wp_unslash ( $_POST['fc_textcolor'] ) ) : array();
			
			$generalsetting['fc_bgcolor']    = isset( $_POST['fc_bgcolor'] ) ? sanitize_text_field( wp_unslash ( $_POST['fc_bgcolor'] ) ) : array();
			$generalsetting['fc_fontfamily']   = isset( $_POST['fc_fontfamily'] ) ? sanitize_text_field( wp_unslash ( $_POST['fc_fontfamily'] ) ) : array();
			
			$generalsetting['fc_inputbg']    = isset( $_POST['fc_inputbg'] ) ? sanitize_text_field( wp_unslash ( $_POST['fc_inputbg'] ) ) : array();
			$generalsetting['fc_inputcolor']   = isset( $_POST['fc_inputcolor'] ) ? sanitize_text_field( wp_unslash ( $_POST['fc_inputcolor'] ) ) : array();
			
			$generalsetting['fc_bordercolor']   = isset( $_POST['fc_bordercolor'] ) ? sanitize_text_field( wp_unslash ( $_POST['fc_bordercolor'] ) ) : array();
			
			$generalsetting['fc_socialpage']   = isset( $_POST['fc_socialpage'] ) ? sanitize_text_field( wp_unslash ( $_POST['fc_socialpage'] ) ) : array();
			
			$result = update_option('fc_gensettings', $generalsetting);
			if(!empty($result)){
				add_action( 'admin_notices', array($this, 'vrs_admindata__success') );
			}
		}
		if(!empty($_POST['wt_column_submit'])){
			$wtdata['wt_column']        = isset( $_POST['wt_column'] ) ? sanitize_text_field( wp_unslash ( $_POST['wt_column'] ) ) : array();
			$result = update_option('fc_wtdata', $wtdata);
			if(!empty($result)){
				add_action( 'admin_notices', array($this, 'vrs_admindata__success') );
			}
		}
		if(!empty($_POST['bt_column_submit'])){
			$btdata['bt_column']        = isset( $_POST['bt_column'] ) ? sanitize_text_field( wp_unslash ( $_POST['bt_column'] ) ) : array();
			$result = update_option('fc_btdata', $btdata);
			if(!empty($result)){
				add_action( 'admin_notices', array($this, 'vrs_admindata__success') );
			}
		}
		if(!empty($_POST['chat_submit'])){
			$data['chatbot_en'] = isset( $_POST['chat_enable'] ) ? sanitize_text_field( wp_unslash ( $_POST['chat_enable'] ) ) : array();
			$data['chatbot_openai'] = isset( $_POST['chat_openaikey'] ) ? sanitize_text_field( wp_unslash ( $_POST['chat_openaikey'] ) ) : array();
			
			$result = update_option('fc_chatbotdata', $data);
			if(!empty($result)){
				add_action( 'admin_notices', array($this, 'vrs_admindata__success') );
			}
		}
		if(!empty($_POST['diet_submit'])){
			$data['diet_heading'] = isset( $_POST['diet_heading'] ) ? sanitize_text_field( wp_unslash ( $_POST['diet_heading'] ) ) : array();
			$result = update_option('fc_diet', $data);
			if(!empty($result)){
				add_action( 'admin_notices', array($this, 'vrs_admindata__success') );
			}
		}
	}
	/**
	 * Function for show success or error message 
	 */
	public function vrs_admindata__success(){
		echo '<div class="notice notice-success is-dismissible">
				<p>'.esc_html__( 'Data has been updated successfully.', 'fc' ).'</p>
			</div>';
	}
	
	/**
	 * Add page templates.
	 *
	 * @param  array  $templates  The list of page templates
	 *
	 * @return array  $templates  The modified list of page templates
	 */
	public function fc_add_page_template_to_dropdown($templates){
		$path = plugin_dir_path(__FILE__);
		$templates[ $path . 'partials/fc-page-template.php'] = __('Page Template From Plugin', 'fc');

		return $templates;
	}

	/**
	 * Change the page template to the selected template on the dropdown
	 * 
	 * @param $template
	 *
	 * @return mixed
	 */
	public function fc_change_page_template($template){
		if (is_page()) {
			$meta = get_post_meta(get_the_ID());

			if (!empty($meta['_wp_page_template'][0]) && $meta['_wp_page_template'][0] != $template) {
				$template = $meta['_wp_page_template'][0];
			}
		}

		return $template;
	}

	public function fc_remove_style(){
		// Change this "my-page" with your page slug
		if (is_page('my-page')) {
			$theme = wp_get_theme();

			$parent_style = $theme->stylesheet . '-style'; 

			wp_dequeue_style($parent_style);
			wp_deregister_style($parent_style);
			wp_deregister_style($parent_style . '-css');
		}
	}
}